@@ -33,7 +33,20 @@ use POSIX ();
 
 package Net::Daemon;
 
-$Net::Daemon::VERSION = '0.43';
+$Net::Daemon::VERSION = '0.44';
+
+# Dummy share() in case we're >= 5.10. If we are, require/import of
+# threads::shared will replace it appropriately.
+my $this_is_510 = $^V ge v5.10.0;
+if ($this_is_510) {
+    no warnings 'redefine';
+    eval { require threads; };
+    eval { require threads::shared; };
+} else {
+    eval { require Threads; };
+}
+
+
 @Net::Daemon::ISA = qw(Net::Daemon::Log);
 
 #
@@ -41,6 +54,7 @@ $Net::Daemon::VERSION = '0.43';
 #   regexp-threads.)
 #
 $Net::Daemon::RegExpLock = 1;
+threads::shared::share(\$Net::Daemon::RegExpLock) if $this_is_510;
 
 use vars qw($exit);
 
@@ -679,7 +693,7 @@ sub Bind ($) {
 		$self->Debug("Child clone: $sth\n");
 		$sth->ChildFunc('HandleChild') if $sth;
 		if ($self->{'mode'} eq 'fork') {
-		    close($client);
+                    $self->ServClose($client);
 		}
 	    }
 	}
@@ -704,6 +718,12 @@ sub Close {
     $socket->close() if $socket;
 }
 
+sub ServClose {
+    my $self = shift;
+    my $socket = shift;
+    $socket->close() if $socket;
+}
+
 
 1;
 
